@@ -135,8 +135,8 @@ class BaseType(object):
         return value
 
     def allow_none(self):
-        if hasattr(self, 'model_class'):
-            return self.model_class.allow_none(self)
+        if hasattr(self, 'owner_model'):
+            return self.owner_model.allow_none(self)
         else:
             return self.serialize_when_none
 
@@ -411,6 +411,12 @@ class DecimalType(BaseType):
     """A fixed-point decimal number field.
     """
 
+    MESSAGES = {
+        'number_coerce': 'Number failed to convert to a decimal',
+        'number_min': u"Value should be greater than {}",
+        'number_max': u"Value should be less than {}",
+    }
+
     def __init__(self, min_value=None, max_value=None, **kwargs):
         self.min_value, self.max_value = min_value, max_value
 
@@ -427,19 +433,18 @@ class DecimalType(BaseType):
                 value = decimal.Decimal(value)
 
             except (TypeError, decimal.InvalidOperation):
-                raise ConversionError(self.messages['number_coerce']
-                    .format(self.number_type))
+                raise ConversionError(self.messages['number_coerce'])
 
         return value
 
     def validate_range(self, value):
         if self.min_value is not None and value < self.min_value:
-            raise ValidationError(self.messages['number_min']
-                .format(self.number_type, self.min_value))
+            error_msg = self.messages['number_min'].format(self.min_value)
+            raise ValidationError(error_msg)
 
         if self.max_value is not None and value > self.max_value:
-            raise ValidationError(self.messages['number_max']
-                .format(self.number_type, self.max_value))
+            error_msg = self.messages['number_max'].format(self.max_value)
+            raise ValidationError(error_msg)
 
         return value
 
@@ -455,7 +460,7 @@ class HashType(BaseType):
         if len(value) != self.LENGTH:
             raise ValidationError(self.messages['hash_length'])
         try:
-            value = int(value, 16)
+            int(value, 16)
         except ValueError:
             raise ConversionError(self.messages['hash_hex'])
         return value
