@@ -29,8 +29,8 @@ class MultiType(BaseType):
 
         return value
 
-    def apply_shape(self, shape_instance, role, field_converter,
-                    shape_converter, print_none=False):
+    def apply_shape(self, shape_instance, field_converter,
+                    role=None, print_none=False):
         raise NotImplemented()
 
 
@@ -80,14 +80,15 @@ class ModelType(MultiType):
 
         return primitive_data
 
-    def apply_shape(self, model_instance, role, field_converter,
-                    shape_converter, print_none=False):
+    def apply_shape(self, model_instance, field_converter, 
+                    role=None, print_none=False):
         """
         Calls the main `apply_shape` implementation because they are both
         supposed to operate on models.
         """
-        shaped =  apply_shape(self.model_class, model_instance, role,
-                              field_converter, shape_converter)
+        shaped =  apply_shape(self.model_class, model_instance,
+                              field_converter, 
+                              role=role, print_none=print_none)
 
         if shaped and len(shaped) == 0 and self.allow_none():
             return shaped
@@ -166,8 +167,8 @@ class ListType(MultiType):
     def to_primitive(self, value):
         return map(self.field.to_primitive, value)
 
-    def apply_shape(self, list_instance, role, field_converter,
-                    shape_converter, print_none=False):
+    def apply_shape(self, list_instance, field_converter, 
+                    role=None, print_none=False):
         """Loops over each item in the model and applies either the field
         transform or the multitype transform.  Essentially functions the same
         as `serialize.apply_shape`.
@@ -175,13 +176,14 @@ class ListType(MultiType):
         data = []
         for value in list_instance:
             if hasattr(self.field, 'apply_shape'):
-                shaped = self.field.apply_shape(value, role,
-                                                field_converter, shape_converter)
+                shaped = self.field.apply_shape(value, field_converter,
+                                                role=role)
                 feels_empty = shaped and len(shaped) == 0
             else:
                 shaped = field_converter(self.field, value)
                 feels_empty = shaped == None
-                
+
+            ### Print if we want empty or found a value
             if (feels_empty and self.allow_none()):
                 data.append(shaped)
             elif shaped is not None:
@@ -189,6 +191,7 @@ class ListType(MultiType):
             elif print_none:
                 data.append(shaped)
 
+        ### Return data if the list contains anything
         if len(data) > 0:
             return data
         elif len(data) == 0 and self.allow_none():
@@ -240,8 +243,8 @@ class DictType(MultiType):
     def to_primitive(self, value):
         return dict((unicode(k), self.field.to_primitive(v)) for k, v in value.iteritems())
 
-    def apply_shape(self, dict_instance, role, field_converter,
-                    shape_converter, print_none=False):
+    def apply_shape(self, dict_instance, field_converter, 
+                    role=None, print_none=False):
         """Loops over each item in the model and applies either the field
         transform or the multitype transform.  Essentially functions the same
         as `serialize.apply_shape`.
@@ -250,8 +253,8 @@ class DictType(MultiType):
         
         for key, value in dict_instance.iteritems():
             if hasattr(self.field, 'apply_shape'):
-                shaped = self.field.apply_shape(value, role,
-                                                field_converter, shape_converter)
+                shaped = self.field.apply_shape(value, field_converter,
+                                                role=role)
                 feels_empty = shaped and len(shaped) == 0
             else:
                 shaped = field_converter(self.field, value)
